Notify

Struct Notify 

pub struct Notify<'a> {
    pub job_id: String,
    pub prev_hash: PrevHash<'a>,
    pub coin_base1: HexBytes,
    pub coin_base2: HexBytes,
    pub merkle_branch: Vec<MerkleNode<'a>>,
    pub version: HexU32Be,
    pub bits: HexU32Be,
    pub time: HexU32Be,
    pub clean_jobs: bool,
}
Fields in order:

  • Job ID: This is included when miners submit a results so work can be matched with proper transactions.
  • Hash of previous block: Used to build the header.
  • Generation transaction (part 1): The miner inserts ExtraNonce1 and ExtraNonce2 after this section of the transaction data.
  • Generation transaction (part 2): The miner appends this after the first part of the transaction data and the two ExtraNonce values.
  • List of merkle branches: The generation transaction is hashed against the merkle branches to build the final merkle root.
  • Bitcoin block version: Used in the block header.
    • nBits: The encoded network difficulty. Used in the block header.
    • nTime: The current time. nTime rolling should be supported, but should not increase faster than actual time.
  • Clean Jobs: If true, miners should abort their current work and immediately use the new job. If false, they can still use the current job, but should move to the new one after exhausting the current nonce range.

Fields

job_id: Stringprev_hash: PrevHash<'a>coin_base1: HexBytescoin_base2: HexBytesmerkle_branch: Vec<MerkleNode<'a>>version: HexU32Bebits: HexU32Betime: HexU32Beclean_jobs: bool