SetExtranonce

Struct SetExtranonce 

pub struct SetExtranonce<'a> {
    pub extra_nonce1: Extranonce<'a>,
    pub extra_nonce2_size: usize,
}
SetExtranonce message (sent if we subscribed with ExtranonceSubscribe)

mining.set_extranonce(“extranonce1”, extranonce2_size)

These values, when provided, replace the initial subscription values beginning with the next mining.notify job.

check if it is a Notification or a StandardRequest this implementation assume that it is a Notification

Fields

extra_nonce1: Extranonce<'a>extra_nonce2_size: usize