Module utils

Module utils 

Structs

Extranonce
Helper type that allows simple serialization and deserialization of byte vectors that are represented as hex strings in JSON. Extranonce must be less than or equal to 32 bytes.
HexBytes
Helper type that allows simple serialization and deserialization of byte vectors that are represented as hex strings in JSON. HexBytes must be less than or equal to 32 bytes.
HexU32Be
Big-endian alternative of the HexU32
MerkleNode
PrevHash
PrevHash in Stratum V1 has brain-damaged serialization as it swaps bytes of every u32 word into big endian. Therefore, we need a special type for it