pub struct SetExtranonce<'a> {
pub extra_nonce1: Extranonce<'a>,
pub extra_nonce2_size: usize,
}Expand description
SetExtranonce message (sent if we subscribed with ExtranonceSubscribe)
mining.set_extranonce(“extranonce1”, extranonce2_size)
These values, when provided, replace the initial subscription values beginning with the next mining.notify job.
check if it is a Notification or a StandardRequest this implementation assume that it is a Notification
Fields
extra_nonce1: Extranonce<'a>extra_nonce2_size: usizeTrait Implementations
Sourceimpl<'a> Clone for SetExtranonce<'a>
impl<'a> Clone for SetExtranonce<'a>
Sourcefn clone(&self) -> SetExtranonce<'a>
fn clone(&self) -> SetExtranonce<'a>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for SetExtranonce<'a>
impl<'a> Debug for SetExtranonce<'a>
Sourceimpl Display for SetExtranonce<'_>
impl Display for SetExtranonce<'_>
Sourceimpl From<SetExtranonce<'_>> for Message
impl From<SetExtranonce<'_>> for Message
Sourcefn from(se: SetExtranonce<'_>) -> Self
fn from(se: SetExtranonce<'_>) -> Self
Converts to this type from the input type.
Sourceimpl TryFrom<Notification> for SetExtranonce<'_>
impl TryFrom<Notification> for SetExtranonce<'_>
Sourcetype Error = ParsingMethodError
type Error = ParsingMethodError
The type returned in the event of a conversion error.