Helper type that allows simple serialization and deserialization of byte vectors
that are represented as hex strings in JSON.
Extranonce must be less than or equal to 32 bytes.
Helper type that allows simple serialization and deserialization of byte vectors
that are represented as hex strings in JSON.
HexBytes must be less than or equal to 32 bytes.